==> ember-cli-htmlbars-0.2.1.tgz: package/test/template_compiler_test.js <==
'use strict';

var fs = require('fs');
var broccoli = require('broccoli');
var assert = require('assert');
var templateCompilerFilter = require('../index');
var htmlbarsCompiler = require('../ext/htmlbars-compiler/compiler').compileSpec;
var handlbarsTemplateCompiler = require('ember-template-compiler');

var builder;

describe('templateCompilerFilter', function(){
  var sourcePath = 'test/fixtures';

  afterEach(function() {
    if (builder) {
      builder.cleanup();
    }
  });

  it('precompiles templates into htmlbars', function(){
    var tree = templateCompilerFilter(sourcePath, { HTMLBars: true });

    builder = new broccoli.Builder(tree);
    return builder.build().then(function(results) {
      var actual = fs.readFileSync(results.directory + '/template.js', { encoding: 'utf8'});
      var source = fs.readFileSync(sourcePath + '/template.hbs', { encoding: 'utf8' });
      var expected = "export default " + htmlbarsCompiler(source);

      assert.equal(actual,expected,'They dont match!')
    });
  });

  describe('handlebars', function() {
    function assertOutput(results) {
      var actual = fs.readFileSync(results.directory + '/template.js', { encoding: 'utf8'});
      var source = fs.readFileSync(sourcePath + '/template.hbs', { encoding: 'utf8' });
      var expected = 'export default Ember.Handlebars.template(' + handlbarsTemplateCompiler.precompile(source, false) + ')';

      assert.equal(actual,expected,'They dont match!')
    }

    it('precompiles templates into handlebars by default', function(){
      var tree = templateCompilerFilter(sourcePath);

      builder = new broccoli.Builder(tree);
      return builder.build().then(assertOutput);
    });

    it('precompiles templates into handlebars when HTMLBars option is false', function(){
      var tree = templateCompilerFilter(sourcePath, { HTMLBars: false });

      builder = new broccoli.Builder(tree);
      return builder.build().then(assertOutput);
    });
  });
});

==> ember-cli-htmlbars-0.2.2.tgz: package/test/template_compiler_test.js <==
'use strict';

var fs = require('fs');
var broccoli = require('broccoli');
var assert = require('assert');
var templateCompilerFilter = require('../index');
var htmlbarsCompiler = require('../ext/htmlbars-compiler/compiler').compileSpec;
var handlbarsTemplateCompiler = require('ember-template-compiler');

var builder;

describe('templateCompilerFilter', function(){
  var sourcePath = 'test/fixtures';

  afterEach(function() {
    if (builder) {
      builder.cleanup();
    }
  });

  it('precompiles templates into htmlbars', function(){
    var tree = templateCompilerFilter(sourcePath, { HTMLBars: true });

    builder = new broccoli.Builder(tree);
    return builder.build().then(function(results) {
      var actual = fs.readFileSync(results.directory + '/template.js', { encoding: 'utf8'});
      var source = fs.readFileSync(sourcePath + '/template.hbs', { encoding: 'utf8' });
      var expected = "var template = " + htmlbarsCompiler(source) + "\nexport default template;";

      assert.equal(actual,expected,'They dont match!')
    });
  });

  describe('handlebars', function() {
    function assertOutput(results) {
      var actual = fs.readFileSync(results.directory + '/template.js', { encoding: 'utf8'});
      var source = fs.readFileSync(sourcePath + '/template.hbs', { encoding: 'utf8' });
      var expected = 'export default Ember.Handlebars.template(' + handlbarsTemplateCompiler.precompile(source, false) + ')';

      assert.equal(actual,expected,'They dont match!')
    }

    it('precompiles templates into handlebars by default', function(){
      var tree = templateCompilerFilter(sourcePath);

      builder = new broccoli.Builder(tree);
      return builder.build().then(assertOutput);
    });

    it('precompiles templates into handlebars when HTMLBars option is false', function(){
      var tree = templateCompilerFilter(sourcePath, { HTMLBars: false });

      builder = new broccoli.Builder(tree);
      return builder.build().then(assertOutput);
    });
  });
});
